import django
from django.conf.urls import patterns, include, url
from django.contrib import admin

if django.VERSION[:2] < (1, 7):
    admin.autodiscover()

urlpatterns = patterns("",
    url(r"^", include(admin.site.urls)),
)




# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.core.validators


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='RedisServer',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.CharField(blank=True, max_length=50, verbose_name='Label', null=True)),
                ('hostname', models.CharField(verbose_name='Hostname', max_length=250, help_text='This can also be the absolute path to a redis socket')),
                ('port', models.IntegerField(default=6379, validators=[django.core.validators.MaxValueValidator(65535), django.core.validators.MinValueValidator(1)], verbose_name='Port', blank=True, null=True)),
                ('password', models.CharField(blank=True, max_length=250, verbose_name='Password', null=True)),
                ('sampling_threshold', models.IntegerField(default=1000, verbose_name='Sampling threshold', help_text='Number of keys after which only a sample (of random keys) is shown on the inspect page.')),
                ('sampling_size', models.IntegerField(default=200, verbose_name='Sampling size', help_text='Number of random keys shown when sampling is used. Note that each key translates to a RANDOMKEY call in redis.')),
            ],
            options={
                'verbose_name_plural': 'Redis Servers',
                'verbose_name': 'Redis Server',
                'permissions': (('can_inspect', 'Can inspect redis servers'),),
            },
            bases=(models.Model,),
        ),
        migrations.AlterUniqueTogether(
            name='redisserver',
            unique_together=set([('hostname', 'port')]),
        ),
    ]



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding unique constraint on 'RedisServer', fields ['hostname', 'port']
        db.create_unique('redisboard_redisserver', ['hostname', 'port'])


    def backwards(self, orm):
        
        # Removing unique constraint on 'RedisServer', fields ['hostname', 'port']
        db.delete_unique('redisboard_redisserver', ['hostname', 'port'])


    models = {
        'redisboard.redisserver': {
            'Meta': {'unique_together': "(('hostname', 'port'),)", 'object_name': 'RedisServer'},
            'hostname': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '250', 'null': 'True', 'blank': 'True'}),
            'port': ('django.db.models.fields.IntegerField', [], {'default': '6379'})
        }
    }

    complete_apps = ['redisboard']



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'RedisServer'
        db.create_table('redisboard_redisserver', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('hostname', self.gf('django.db.models.fields.CharField')(max_length=250)),
            ('port', self.gf('django.db.models.fields.IntegerField')(default=6379)),
            ('password', self.gf('django.db.models.fields.CharField')(max_length=250, null=True, blank=True)),
        ))
        db.send_create_signal('redisboard', ['RedisServer'])


    def backwards(self, orm):
        
        # Deleting model 'RedisServer'
        db.delete_table('redisboard_redisserver')


    models = {
        'redisboard.redisserver': {
            'Meta': {'object_name': 'RedisServer'},
            'hostname': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '250', 'null': 'True', 'blank': 'True'}),
            'port': ('django.db.models.fields.IntegerField', [], {'default': '6379'})
        }
    }

    complete_apps = ['redisboard']



#!/bin/sh -e
'''echo'
export PYTHONPATH=.
export DJANGO_SETTINGS_MODULE=run_redisboard
secret() {
    tr -cd "[:alnum:]" < /dev/urandom | head -c ${1:-8}
}
chmod u+x run_redisboard.py
if [ "$1" = "--develop" ]; then
    shift
    REDISBOARD="-e ."
else
    REDISBOARD="django-redisboard"
fi

if [ ! -e .redisboard.venv ]; then
    virtualenv .redisboard.venv
    .redisboard.venv/bin/pip install --quiet Django $REDISBOARD
fi
if [ -e .redisboard.venv/bin/activate.sh ]; then
    . .redisboard.venv/bin/activate.sh
else
    . .redisboard.venv/bin/activate
fi
if [ ! -e .redisboard.secret ]; then
    echo $(secret 32) > .redisboard.secret
fi
python run_redisboard.py $*
exit
'''
from __future__ import print_function
import os
import sys
CACHES = {
    'default': {
        'BACKEND': 'django.core.cache.backends.locmem.LocMemCache',
    }
}
SESSION_ENGINE = 'django.contrib.sessions.backends.db'
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': '.redisboard.sqlite',
    }
}
INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.staticfiles',
    'django.contrib.admin',
    'redisboard',
)
MIDDLEWARE_CLASSES = (
    'django.middleware.gzip.GZipMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
)
SECRET_KEY = open('.redisboard.secret').read().strip()
ROOT_URLCONF = 'run_redisboard'
STATIC_URL = '/static/'
ALLOWED_HOSTS = ['*']
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'default': {
            'format': '[%(asctime)s] %(levelname)s | %(name)s - %(message)s',
            'datefmt': "%d/%b/%Y %H:%M:%S",
        }
    },
    'handlers': {
        'console': {
            'level': 'DEBUG',
            'class': 'logging.StreamHandler',
            'formatter': 'default'
        },
    },
    'loggers': {
        'django.request': {
            'handlers': ['console'],
            'level': 'DEBUG',
            'propagate': True,
        },
        "": {
            'handlers': ['console'],
            'level': 'INFO',
            'propagate': False
        },
    }
}
from django.conf import settings
if not settings.configured:
    settings.configure(**{k: v for k, v in globals().items() if k.isupper()})

from django.conf.urls import patterns, include, url
from django.contrib import admin
urlpatterns = patterns("",
    url(r"^static/(?P<path>.*)$", 'django.contrib.staticfiles.views.serve', {'insecure': True}),
    url(r"^", include(admin.site.urls)),
)


if __name__ == '__main__':
    import django
    django.setup()
    from django.core.management import execute_from_command_line
    if not os.path.exists('.redisboard.sqlite'):
        execute_from_command_line(['run_redisboard', 'syncdb', '--noinput'])
        from django.contrib.auth.models import User
        u = User.objects.create(username='redisboard', is_superuser=True, is_staff=True, is_active=True)
        pwd = os.urandom(8).encode('hex')
        u.set_password(pwd)
        u.save()
        print()
        print("="*80)
        print("""
        Credentials:

            USERNAME: redisboard
            PASSWORD: %s

        """ % pwd)
        print("="*80)
        print()
        from redisboard.models import RedisServer
        RedisServer.objects.create(label="localhost", hostname="127.0.0.1")
    execute_from_command_line(['run_redisboard', 'runserver', '--noreload'] + (sys.argv[1:] if len(sys.argv) > 1 else ['0:8000']))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from __future__ import absolute_import, print_function, unicode_literals

import os
import sys
from os.path import exists
from os.path import join


if __name__ == "__main__":
    base_path = join(".tox", "configure")
    if sys.platform == "win32":
        bin_path = join(base_path, "Scripts")
    else:
        bin_path = join(base_path, "bin")
    if not exists(base_path):
        import subprocess
        print("Bootstrapping ...")
        try:
            subprocess.check_call(["virtualenv", base_path])
        except Exception:
            subprocess.check_call([sys.executable, "-m", "virtualenv", base_path])
        print("Installing `jinja2` and `matrix` into bootstrap environment ...")
        subprocess.check_call([join(bin_path, "pip"), "install", "jinja2", "matrix"])
    activate = join(bin_path, "activate_this.py")
    exec(compile(open(activate, "rb").read(), activate, "exec"), dict(__file__=activate))

    import jinja2
    import matrix

    jinja = jinja2.Environment(
        loader=jinja2.FileSystemLoader(join("ci", "templates")),
        trim_blocks=True,
        lstrip_blocks=True,
        keep_trailing_newline=True
    )
    tox_environments = {}
    for (alias, conf) in matrix.from_file("setup.cfg").items():
        python = conf["python_versions"]
        deps = conf["dependencies"]
        if "coverage_flags" in conf:
            cover = {"false": False, "true": True}[conf["coverage_flags"].lower()]
        if "environment_variables" in conf:
            env_vars = conf["environment_variables"]

        tox_environments[alias] = {
            "python": "python" + python if "py" not in python else python,
            "deps": deps.split(),
        }
        if "coverage_flags" in conf:
            tox_environments[alias].update(cover=cover)
        if "environment_variables" in conf:
            tox_environments[alias].update(env_vars=env_vars.split())

    for name in os.listdir(join("ci", "templates")):
        with open(name, "w") as fh:
            fh.write(jinja.get_template(name).render(tox_environments=tox_environments))
        print("Wrote {}".format(name))
    print("DONE.")
